//
//  TableViewController.swift
//  SO-34996964
//
//  Copyright © 2016 Xavier Schott
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
//

import UIKit

    class TableViewController: UITableViewController {

        var cacheSelectedRows:[NSIndexPath]? = nil
        
        override func viewDidLoad() {
            super.viewDidLoad()

            tableView.estimatedRowHeight = 160
            tableView.rowHeight = UITableViewAutomaticDimension
        }
        override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
            return 8
        }

        override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
            let cell = tableView.dequeueReusableCellWithIdentifier("reuseIdentifier", forIndexPath: indexPath)
            
            if let textLabel = cell.textLabel {
                textLabel.backgroundColor = UIColor.clearColor()
                
                textLabel.numberOfLines = 1
                if let cacheSelectedRows = cacheSelectedRows {
                    textLabel.numberOfLines = (cacheSelectedRows.contains(indexPath)) ? 0 : 1
                }
                textLabel.text = "\(1 + indexPath.row), Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."
            }
            return cell
        }

        override func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
            self.reloadRowsAtIndexPaths(tableView, indexPath:indexPath)
       }
        
        override func tableView(tableView: UITableView, didDeselectRowAtIndexPath indexPath: NSIndexPath) {
            self.reloadRowsAtIndexPaths(tableView, indexPath:indexPath)
        }

        func reloadRowsAtIndexPaths(tableView: UITableView, indexPath: NSIndexPath) {
            cacheSelectedRows = tableView.indexPathsForSelectedRows

            tableView.reloadRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)

            // Restore selection
            if let cacheSelectedRows = cacheSelectedRows {
                for path in cacheSelectedRows {
                    self.tableView.selectRowAtIndexPath(path, animated: false, scrollPosition: .None)
                }
            }
        }
    }
